@@ -209,7 +209,7 @@ class Quality(object):
                 stat = Quality.statusPrefixes[status]
                 qual = Quality.qualityStrings[quality]
                 comp = Quality.compositeStatus(status, quality)
-                to_return[comp] = "{0} ({1})".format(stat, qual)
+                to_return[comp] = f"{stat} ({qual})"
         return to_return
 
     @staticmethod
