@@ -1,20 +1,15 @@
 from urllib.parse import urljoin
 
 import requests
+from requests import RequestException
+from requests.structures import CaseInsensitiveDict
 
 from sickchill import logger, settings
 
 
 class Notifier(object):
-    def __init__(self):
-        self.session = None
-
-    def __make_session(self, emby_apikey=None):
-        if not self.session:
-            self.session = requests.Session()
-
-        self.session.headers.update({"X-Emby-Token": emby_apikey or settings.EMBY_APIKEY, "Content-Type": "application/json"})
-        return self.session
+    def _make_headers(self, emby_apikey=None):
+        return CaseInsensitiveDict({"X-Emby-Token": emby_apikey or settings.EMBY_APIKEY, "Content-Type": "application/json"})
 
     def _notify_emby(self, message, host=None, emby_apikey=None):
         """Handles notifying Emby host via HTTP API
@@ -27,15 +22,14 @@ class Notifier(object):
         params = {"Name": "SickChill", "Description": message, "ImageUrl": settings.LOGO_URL}
 
         try:
-            session = self.__make_session(emby_apikey)
-            response = session.get(url, params=params)
+            response = requests.get(url, params=params, headers=self._make_headers(emby_apikey))
             if response:
-                logger.debug("EMBY: HTTP response: {0}".format(response.text.replace("\n", "")))
+                logger.debug(_(f"EMBY: HTTP response: {response.content}"))
             response.raise_for_status()
 
             return True
-        except requests.exceptions.RequestException as error:
-            logger.warning(f"EMBY: Warning: Could not contact Emby at {url} {error}")
+        except RequestException as error:
+            logger.warning(_(f"EMBY: Warning: Could not contact Emby at {url} {error}"))
             return False
 
     ##############################################################################
@@ -43,7 +37,7 @@ class Notifier(object):
     ##############################################################################
 
     def test_notify(self, host, emby_apikey):
-        return self._notify_emby("This is a test notification from SickChill", host, emby_apikey)
+        return self._notify_emby(_("This is a test notification from SickChill"), host, emby_apikey)
 
     def update_library(self, show=None):
         """Handles updating the Emby Media Server host via HTTP API
@@ -55,7 +49,7 @@ class Notifier(object):
 
         if settings.USE_EMBY:
             if not settings.EMBY_HOST:
-                logger.debug("EMBY: No host specified, check your settings")
+                logger.debug(_("EMBY: No host specified, check your settings"))
                 return False
 
             params = {}
@@ -67,13 +61,12 @@ class Notifier(object):
                 url = urljoin(settings.EMBY_HOST, "emby/Library/Refresh")
 
             try:
-                session = self.__make_session()
-                response = session.post(url, params=params)
+                response = requests.post(url, params=params, headers=self._make_headers())
                 response.raise_for_status()
-                logger.debug("EMBY: HTTP status: {0}, response: {1}".format(response.status_code, response.text.replace("\n", "")))
+                logger.debug(_(f"EMBY: HTTP status: {response.status_code}, response: {response.content}"))
                 return True
 
             except requests.exceptions.RequestException as error:
-                logger.warning(f"EMBY: Warning: Could not contact Emby at {url} {error}")
+                logger.warning(_(f"EMBY: Warning: Could not contact Emby at {url} {error}"))
 
                 return False
