@@ -17,7 +17,6 @@ from sickchill.oldbeard.providers import (
     elitetorrent,
     eztv,
     filelist,
-    gftracker,
     gimmepeers,
     hd4free,
     hdbits,
@@ -75,7 +74,6 @@ __all__ = [
     "elitetorrent",
     "eztv",
     "filelist",
-    "gftracker",
     "gimmepeers",
     "hd4free",
     "hdbits",
