@@ -1,7 +1,6 @@
 import re
 from urllib.parse import urljoin
 
-import js2py
 import validators
 
 from sickchill import logger
@@ -68,7 +67,7 @@ class Provider(TorrentProvider):
     def _get_provider_url(self):
         if self._recheck_url:
             if self.custom_url:
-                if validators.url(self.custom_url):
+                if validators.url(self.custom_url) == True:
                     self._used_url = self.custom_url
                 else:
                     logger.warning("Invalid custom url set, please check your settings")
