@@ -13,13 +13,12 @@ from guessit import guessit
 
 import sickchill.oldbeard.helpers
 from sickchill import logger, settings
-from sickchill.helper.common import dateTimeFormat, episode_num
+from sickchill.helper.common import dateTimeFormat, episode_num, is_media_file
 from sickchill.show.History import History
 from sickchill.show.Show import Show
 
 from . import db
 from .common import Quality
-from .helpers import is_media_file
 
 # https://github.com/Diaoul/subliminal/issues/536
 # provider_manager.register('napiprojekt = subliminal.providers.napiprojekt:NapiProjektProvider')
@@ -55,7 +54,7 @@ PROVIDER_URLS = {
 
 
 max_score = {}
-Scores = namedtuple("Scores", ["res", "percent", "min", "min_percent"])
+Scores = namedtuple("Scores", "res percent min min_percent")
 
 
 def log_scores(subtitle: Union[subliminal.Episode, subliminal.Movie], video: subliminal.Video, user_score: int = None) -> Scores:
@@ -254,7 +253,7 @@ def download_subtitles(episode, force_lang=None):
         for subtitle in subtitles_list:
             scores = log_scores(subtitle, video, user_score=user_score)
             logger.debug(
-                f"[{subtitle.provider_name}] Subtitle score for {subtitle.id} is: {scores['res']}/{scores['percent']}% (min={scores['min']}/{scores['min_percent']}%)"
+                f"[{subtitle.provider_name}] Subtitle score for {subtitle.id} is: {scores.res}/{scores.percent}% (min={scores.min}/{scores.min_percent}%)"
             )
 
         found_subtitles = pool.download_best_subtitles(
