@@ -3,6 +3,8 @@ import time
 
 import certifi
 import requests
+from requests.exceptions import RequestException
+from requests.structures import CaseInsensitiveDict
 
 from sickchill import logger, settings
 
@@ -11,12 +13,11 @@ from .exceptions import traktException
 
 class TraktAPI:
     def __init__(self, ssl_verify=True, timeout=30):
-        self.session = requests.Session()
         self.verify = certifi.where() if ssl_verify else False
         self.timeout = timeout if timeout else None
         self.auth_url = settings.TRAKT_OAUTH_URL
         self.api_url = settings.TRAKT_API_URL
-        self.headers = {"Content-Type": "application/json", "trakt-api-version": "2", "trakt-api-key": settings.TRAKT_API_KEY}
+        self.headers = CaseInsensitiveDict({"Content-Type": "application/json", "trakt-api-version": "2", "trakt-api-key": settings.TRAKT_API_KEY})
 
     def traktToken(self, trakt_pin=None, refresh=False, count=0):
 
@@ -36,7 +37,7 @@ class TraktAPI:
             if trakt_pin:
                 data["code"] = trakt_pin
 
-        headers = {"Content-Type": "application/json"}
+        headers = CaseInsensitiveDict({"Content-Type": "application/json"})
 
         resp = self.traktRequest("oauth/token", data=data, headers=headers, url=self.auth_url, method="POST", count=count)
 
@@ -65,32 +66,32 @@ class TraktAPI:
             headers = self.headers
 
         if settings.TRAKT_ACCESS_TOKEN == "" and count >= 2:
-            logger.warning("You must get a Trakt TOKEN. Check your Trakt settings")
+            logger.warning(_("You must get a Trakt TOKEN. Check your Trakt settings"))
             return {}
 
         if settings.TRAKT_ACCESS_TOKEN != "":
             headers["Authorization"] = "Bearer " + settings.TRAKT_ACCESS_TOKEN
 
         try:
-            resp = self.session.request(method, url + path, headers=headers, timeout=self.timeout, data=json.dumps(data) if data else [], verify=self.verify)
+            resp = requests.request(method, url + path, headers=headers, timeout=self.timeout, data=json.dumps(data) if data else [], verify=self.verify)
 
             # check for http errors and raise if any are present
             resp.raise_for_status()
 
             # convert response to json
             resp = resp.json()
-        except requests.exceptions.RequestException as e:
-            code = getattr(e.response, "status_code", None)
+        except RequestException as error:
+            code = getattr(error.response, "status_code", None)
             if not code:
-                if "timed out" in e:
-                    logger.warning("Timeout connecting to Trakt. Try to increase timeout value in Trakt settings")
+                if "timed out" in error:
+                    logger.warning(_("Timeout connecting to Trakt. Try to increase timeout value in Trakt settings"))
                 # This is pretty much a fatal error if there is no status_code
                 # It means there basically was no response at all
                 else:
-                    logger.debug("Could not connect to Trakt. Error: {0}".format(e))
+                    logger.debug(_(f"Could not connect to Trakt. Error: {error}"))
             elif code == 502:
                 # Retry the request, cloudflare had a proxying issue
-                logger.debug("Retrying trakt api request: %s" % path)
+                logger.debug(_(f"Retrying trakt api request: {path}"))
                 return self.traktRequest(path, data, headers, url, method)
             elif code == 401:
                 if self.traktToken(refresh=True, count=count):
@@ -99,11 +100,11 @@ class TraktAPI:
                     logger.warning("Unauthorized. Please check your Trakt settings")
             elif code in (500, 501, 503, 504, 520, 521, 522):
                 # http://docs.trakt.apiary.io/#introduction/status-codes
-                logger.debug("Trakt may have some issues and it's unavailable. Try again later please")
+                logger.debug(_("Trakt may have some issues and it's unavailable. Try again later please"))
             elif code == 404:
-                logger.debug("Trakt error (404) the resource does not exist: %s" % url + path)
+                logger.debug(_(f"Trakt error (404) the resource does not exist: {url}{path}"))
             else:
-                logger.exception("Could not connect to Trakt. Code error: {0}".format(code))
+                logger.exception(_(f"Could not connect to Trakt. Code error: {code}"))
             return {}
 
         # check and confirm trakt call did not fail
