@@ -255,6 +255,7 @@ NAMING_MULTI_EP = False
 NAMING_PATTERN = None
 NAMING_SPORTS_PATTERN = None
 NAMING_STRIP_YEAR = False
+NAMING_NO_BRACKETS = False
 NEWS_LAST_READ = None
 NEWS_LATEST = None
 NEWS_UNREAD = 0
@@ -277,6 +278,7 @@ NMJv2_DATABASE = None
 NMJv2_DBLOC = None
 NMJv2_HOST = None
 NO_DELETE = False
+NO_LGMARGIN = False
 NO_RESIZE = False
 NO_RESTART = False
 notificationsTaskScheduler = None
@@ -419,7 +421,7 @@ SUBTITLES_PERFECT_MATCH = False
 SUBTITLES_SERVICES_ENABLED = []
 SUBTITLES_SERVICES_LIST = []
 subtitlesFinderScheduler = None
-SYNC_FILES = "!sync,lftp-pget-status,bts,!qb,!qB"
+SYNC_FILES = "!sync,lftp-pget-status,bts,!qb"
 SYNOLOGY_DSM_HOST = None
 SYNOLOGY_DSM_PASSWORD = None
 SYNOLOGY_DSM_PATH = None
