@@ -13,9 +13,6 @@ from .index import Config
 
 @Route("/config/anime(/?.*)", name="config:anime")
 class ConfigAnime(Config):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
     @addslash
     def index(self, *args_, **kwargs_):
 
