@@ -13,9 +13,6 @@ from . import Config
 
 @Route("/config/subtitles(/?.*)", name="config:subtitles")
 class ConfigSubtitles(Config):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
     @addslash
     def index(self, *args_, **kwargs_):
         t = PageTemplate(rh=self, filename="config_subtitles.mako")
