@@ -10,6 +10,7 @@ from operator import attrgetter
 from pathlib import Path
 from urllib.parse import unquote_plus
 
+import requests
 from github.GithubException import GithubException
 from tornado.escape import xhtml_unescape
 
@@ -47,9 +48,6 @@ from .routes import Route
 
 @Route("/home(/?.*)", name="home")
 class Home(WebRoot):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
     def _genericMessage(self, subject=None, message=None):
         t = PageTemplate(rh=self, filename="genericMessage.mako")
         return t.render(message=message, subject=subject, topmenu="home", title="")
@@ -397,7 +395,7 @@ class Home(WebRoot):
 
         import validators
 
-        if not validators.url(webhook):
+        if validators.url(webhook) != True:
             return _("Invalid URL for webhook")
 
         result = notifiers.discord_notifier.test_notify(webhook, name, avatar, tts)
@@ -535,6 +533,18 @@ class Home(WebRoot):
         blacklist_name = self.get_body_argument("blacklist_name")
         return notifiers.trakt_notifier.test_notify(username, blacklist_name)
 
+    def testFlareSolverr(self):
+        uri = self.get_body_argument("flaresolverr_uri")
+        logger.debug(_(f"Checking flaresolverr uri: {uri}"))
+        try:
+            requests.head(uri)
+            result = _("Successfully connected to flaresolverr, this is experimental!")
+        except (requests.ConnectionError, requests.RequestException):
+            result = _("Failed to connect to flaresolverr")
+
+        logger.debug(_(f"Flaresolverr result: {result}"))
+        return result
+
     @staticmethod
     def loadShowNotifyLists():
 
@@ -1711,7 +1721,7 @@ class Home(WebRoot):
             result = json.dumps({"result": "failure", "message": _("Result not found in the cache")})
 
         if isinstance(result, str):
-            sickchill.oldbeard.logger.info(_("Could not snatch manually selected result: {}").format(result))
+            sickchill.logger.info(_(f"Could not snatch manually selected result: {result}"))
         elif isinstance(result, sickchill.oldbeard.classes.SearchResult):
             sickchill.oldbeard.search.snatchEpisode(result, SNATCHED_BEST)
 
